==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/c2/c246228069a934c6882169683f46bab3.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Model/DefaultValueTrait.php */
class __TwigTemplate_7cf833bb474ba519a0d63b4a35a7127c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Model;

use Mautic\\LeadBundle\\Entity\\CustomFieldEntityInterface;

trait DefaultValueTrait
{
    /**
     * @param string \$object
     */
    protected function setEntityDefaultValues(CustomFieldEntityInterface \$entity, \$object = 'lead')
    {
        if (!\$entity->getId()) {
            \$fields = \$this->leadFieldModel->getFieldListWithProperties(\$object);
            foreach (\$fields as \$alias => \$field) {
                // Prevent defaults from overwriting values already set
                \$value = \$entity->getFieldValue(\$alias);

                if ((null === \$value || '' === \$value) && '' !== \$field['defaultValue'] && null !== \$field['defaultValue']) {
                    \$entity->addUpdatedField(\$alias, \$field['defaultValue']);
                }
            }
        }
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Model/DefaultValueTrait.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Model/DefaultValueTrait.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Model/DefaultValueTrait.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/c2/c246228069a934c6882169683f46bab3.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Model/DefaultValueTrait.php */
class __TwigTemplate_7cf833bb474ba519a0d63b4a35a7127c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Model;

use Mautic\\LeadBundle\\Entity\\CustomFieldEntityInterface;

trait DefaultValueTrait
{
    /**
     * @param string \$object
     */
    protected function setEntityDefaultValues(CustomFieldEntityInterface \$entity, \$object = 'lead')
    {
        if (!\$entity->getId()) {
            \$fields = \$this->leadFieldModel->getFieldListWithProperties(\$object);
            foreach (\$fields as \$alias => \$field) {
                // Prevent defaults from overwriting values already set
                \$value = \$entity->getFieldValue(\$alias);

                if ((null === \$value || '' === \$value) && '' !== \$field['defaultValue'] && null !== \$field['defaultValue']) {
                    \$entity->addUpdatedField(\$alias, \$field['defaultValue']);
                }
            }
        }
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Model/DefaultValueTrait.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Model/DefaultValueTrait.php", "/var/www/html/production-demo/app/bundles/LeadBundle/Model/DefaultValueTrait.php");
    }
}
